summaryrefslogtreecommitdiffstats
path: root/kig/objects/object_drawer.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:18:52 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:18:52 +0000
commit648ba4a456d3aad2825193ff8f3bd52a875783b5 (patch)
tree0b50d2253a0c85238cc4dcba5c4f949de3f0eb15 /kig/objects/object_drawer.h
parent98a12d05a48814bec3870b9a6d5865475cfa1c95 (diff)
downloadtdeedu-648ba4a456d3aad2825193ff8f3bd52a875783b5.tar.gz
tdeedu-648ba4a456d3aad2825193ff8f3bd52a875783b5.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1212481 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kig/objects/object_drawer.h')
-rw-r--r--kig/objects/object_drawer.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kig/objects/object_drawer.h b/kig/objects/object_drawer.h
index c9c962dd..6206522e 100644
--- a/kig/objects/object_drawer.h
+++ b/kig/objects/object_drawer.h
@@ -64,11 +64,11 @@ public:
*/
void draw( const ObjectImp& imp, KigPainter& p, bool selected ) const;
/**
* returns whether the object \p imp tqcontains coordinate \p p . This is
* dependent on whether it is shown ( when it will never contain
* anything ), and on its width..
*/
- bool tqcontains( const ObjectImp& imp, const Coordinate& pt, const KigWidget& w, bool nv = false ) const;
+ bool contains( const ObjectImp& imp, const Coordinate& pt, const KigWidget& w, bool nv = false ) const;
/**
* returns whether the object \p imp is in the rectangle \p r . This is
* dependent on whether it is shown and on its width..
@@ -64,11 +64,11 @@ public:
void draw( const ObjectImp& imp, KigPainter& p, bool selected ) const;
/**
- * returns whether the object \p imp tqcontains coordinate \p p . This is
+ * returns whether the object \p imp contains coordinate \p p . This is
* dependent on whether it is shown ( when it will never contain
* anything ), and on its width..